@@ -35,7 +35,7 @@ double beta1=2.0,beta2=100.0;
 double BigC14[BigCalSize],BigSigma[BigCalSize];
 
 FILE *CalFile;
-int i;
+int i,result;
 
 CalFile = fopen(*CALPATH,"r");
 
@@ -49,8 +49,8 @@ if(CalFile==NULL) {
     // Now read in
     for(i=0;i<BigCalSize;i++)
     {
-       fscanf(CalFile,"%lf",&BigC14[i]);                       
-       fscanf(CalFile,"%lf",&BigSigma[i]);                                           
+       result=fscanf(CalFile,"%lf",&BigC14[i]);                       
+       result=fscanf(CalFile,"%lf",&BigSigma[i]);                                           
     }
 
     fclose(CalFile);
@@ -78,6 +78,7 @@ Rprintf("========================= \n");
     Rprintf("End of data. \n");
     Rprintf("========================= \n");
 
+
 ///////////////////// STARTING VALUES ////////////////////////////
 
 // Create starting values for dates
@@ -145,6 +146,13 @@ c0 = clock();
 // Start iterations here 
 for (iter=0;iter<*m;iter++)
 {  
+	//if(iter==687) {
+//		for(k=0;k<*ndets;k++) Rprintf("k=%i, piytheta = %lf \n",k,piytheta[k]);
+//		for(k=0;k<*ndets-1;k++) Rprintf("k=%i, pixtheta = %lf \n",k,pixtheta[k]);
+//		Rprintf("piytwmean = %lf, pixtwmean = %lf \n",piytwmean,pixtwmean);
+//		Rprintf("piytwpsi = %lf, pixtwpsi = %lf \n",piytwpsi,pixtwpsi);
+//	} else {
+	
 
     // Get a new seed
     GetRNGstate();
@@ -176,7 +184,7 @@ for (iter=0;iter<*m;iter++)
     if(iter % *thinby == 0 && iter > *burnin) fprintf(parameterfile,"%lf %lf \n", mean,psi);
 
     ///////////////////////////////// DEPTHS ////////////////////////////////////////
-  
+
     // Use thickness to update the current set of depths used for this particular run
     for(k=0;k<*ndets;k++) {
         currentdepths[k] = runif(depth[k]-thick[k]/2,depth[k]+thick[k]/2);
@@ -381,6 +389,9 @@ for (iter=0;iter<*m;iter++)
 		}
         
 	}
+	if(iter < 687) {
+	// Only going to do this bit for the first 686 iterations - all the rest is done for 687
+
 
     for(q1=0; q1<*ndets; q1++)
 	{	
@@ -493,6 +504,7 @@ for (iter=0;iter<*m;iter++)
     // Sort out the RNG state
     PutRNGstate();
 
+	}
 // End of iterations loop
 }
 
@@ -501,7 +513,7 @@ fclose(parameterfile);
 c1 = clock();
 Rprintf("Completed!\n");
 Rprintf("Elapsed time in sec: %5.2f\n",(float) (c1 - c0)/CLOCKS_PER_SEC,2);
-Rprintf("Elapsed time in minutes: %5.2f\n",(float) (c1 - c0)/(60*CLOCKS_PER_SEC));    
-Rprintf("Elapsed time in hours: %5.2f\n",(float) (c1 - c0)/(60*60*CLOCKS_PER_SEC));
+Rprintf("Elapsed time in minutes: %5.2f\n",(float) (c1 - c0)/(60ul*CLOCKS_PER_SEC));    
+Rprintf("Elapsed time in hours: %5.2f\n",(float) (c1 - c0)/(60ul*60ul*CLOCKS_PER_SEC));
 
 }
